package kr.co.iyapp.todayen.activity;

import androidx.appcompat.app.AppCompatActivity;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.nfc.Tag;
import android.os.Bundle;
import android.speech.tts.TextToSpeech;
import android.util.Log;
import android.view.KeyEvent;
import android.view.WindowManager;
import android.webkit.WebChromeClient;
import android.webkit.WebResourceRequest;
import android.webkit.WebView;
import android.webkit.WebViewClient;

import org.json.JSONArray;

import java.util.Locale;

import kr.co.iyapp.todayen.R;
import kr.co.iyapp.todayen.dao.TodayEnglishDAO;
import kr.co.iyapp.todayen.util.HtmlBridge;

public class StudyActivity extends AppCompatActivity  {

    private WebView webView;
    private TextToSpeech tts;
    private Context context;

    @SuppressLint("SetJavaScriptEnabled")
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_study);
        this.context = this.getApplicationContext();

        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        // TTS를 생성하고 OnInitListener로 초기화 한다.
        tts = new TextToSpeech(StudyActivity.this, new TextToSpeech.OnInitListener() {
            @Override
            public void onInit(int status) {
                if(status != TextToSpeech.ERROR) {
                    // 언어를 선택한다.
                    tts.setLanguage(Locale.ENGLISH);
                }else{
                    Log.d("TTSSTART" , "TTS 시작 오류 발생!!!");
                }
            }
        });

        // 웹뷰 셋팅
        webView = (WebView) findViewById(R.id.webView);
        webView.getSettings().setJavaScriptEnabled(true); //자바스크립트 허용

        webView.loadUrl("file:///android_asset/html/study.html");
        webView.setWebChromeClient(new WebChromeClient());  // 새창 띄우지 않기
        webView.setWebViewClient(new StudyActivity.WevViewClientClass());
        webView.setWebContentsDebuggingEnabled(true);

        Intent intent = getIntent();
        String selectDate = intent.getStringExtra("selectDate")==null?"":intent.getStringExtra("selectDate");

        webView.addJavascriptInterface(new HtmlBridge(webView, StudyActivity.this, tts , selectDate), "connector");
    }

    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if ((keyCode == KeyEvent.KEYCODE_BACK) && webView.canGoBack()) {
            webView.goBack();
            Activity act = (Activity) this.context;
            act.finish();
            return true;
        }
        return super.onKeyDown(keyCode, event);
    }

    private class WevViewClientClass extends WebViewClient {
        @Override
        public boolean shouldOverrideUrlLoading(WebView view, WebResourceRequest request) {
            String url = String.valueOf(request.getUrl());

            if( url.startsWith("app://testAcitivity") ){  // 현재 uri의 path에 컨테인만 읽기
                Intent intent = new Intent(StudyActivity.this, TestActivity.class); // 새창을 여는 액티비티나, 팝업일때 이용하면 용이합니다.
                intent.putExtra("url",view.getUrl());
                startActivity(intent);
                return true;
            }
            return super.shouldOverrideUrlLoading(view, request);
        }
    }

    @Override
    protected void onDestroy() {
        tts.stop();
        tts.shutdown();
        super.onDestroy();
    }

}