package kr.co.iyapp.todayen.activity;

import androidx.appcompat.app.AppCompatActivity;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.speech.tts.TextToSpeech;
import android.util.Log;
import android.view.KeyEvent;
import android.view.WindowManager;
import android.webkit.WebChromeClient;
import android.webkit.WebResourceRequest;
import android.webkit.WebView;
import android.webkit.WebViewClient;

import java.util.Locale;

import kr.co.iyapp.todayen.R;
import kr.co.iyapp.todayen.util.HtmlBridge;

public class TestActivity extends AppCompatActivity {

    private WebView webView;
    private Context context;
    private TextToSpeech tts;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_test);
        context = this.getApplicationContext();
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        // TTS를 생성하고 OnInitListener로 초기화 한다.
        tts = new TextToSpeech(TestActivity.this, new TextToSpeech.OnInitListener() {
            @Override
            public void onInit(int status) {
                if(status != TextToSpeech.ERROR) {
                    // 언어를 선택한다.
                    tts.setLanguage(Locale.ENGLISH);
                }else{
                    Log.d("TTS START" , "TTS 시작 오류 발생!!!");
                }
            }
        });

        // 웹뷰 셋팅
        webView = (WebView) findViewById(R.id.webView);
        webView.getSettings().setJavaScriptEnabled(true); //자바스크립트 허용

        webView.setWebChromeClient(new WebChromeClient());  // 새창 띄우지 않기
        webView.setWebViewClient(new TestActivity.WevViewClientClass());

        Intent intent = getIntent();
        String selectDate = intent.getStringExtra("selectDate") == null?"": intent.getStringExtra("selectDate");
        String reverseGbn = intent.getStringExtra("reverseGbn") == null?"N": intent.getStringExtra("reverseGbn");
        String url ="file:///android_asset/html/test.html";
        if("Y".equals(reverseGbn)){
            url ="file:///android_asset/html/reverseTest.html";
        }
        webView.loadUrl(url);

        webView.addJavascriptInterface(new HtmlBridge(webView, TestActivity.this, tts , selectDate), "connector");

    }

    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if ((keyCode == KeyEvent.KEYCODE_BACK) && webView.canGoBack()) {
            webView.goBack();
            Activity act = (Activity) this.context;
            act.finish();
            return true;
        }
        return super.onKeyDown(keyCode, event);
    }

    public class WevViewClientClass extends WebViewClient {
        @Override
        public boolean shouldOverrideUrlLoading(WebView view, WebResourceRequest request) {
            String url = String.valueOf(request.getUrl());

            if( url.startsWith("app://config") ){  // 현재 uri의 path에 컨테인만 읽기
                Intent intent = new Intent(TestActivity.this, ConfigActivity.class); // 새창을 여는 액티비티나, 팝업일때 이용하면 용이합니다.
                intent.putExtra("url",view.getUrl());
                startActivity(intent);
                return true;
            }
            return super.shouldOverrideUrlLoading(view, request);
        }
    }
}